@@ -1,6 +1,6 @@
 package Devel::FindPerl;
 {
-  $Devel::FindPerl::VERSION = '0.002';
+  $Devel::FindPerl::VERSION = '0.003';
 }
 use strict;
 use warnings;
@@ -12,6 +12,7 @@ use Carp;
 use Cwd;
 use ExtUtils::Config;
 use File::Spec;
+use IPC::Open2;
 
 sub find_perl_interpreter {
 	my $config = shift || ExtUtils::Config->new;
@@ -109,12 +110,12 @@ sub _perl_is_same {
 	# from a different configuration that happens to be already
 	# installed in @INC.
 	push @cmd, '-I' . File::Spec->catdir(File::Basename::dirname($perl), 'lib') if $ENV{PERL_CORE};
-
 	push @cmd, qw(-MConfig=myconfig -e print -e myconfig);
-	open my $fh, '-|', @cmd or return;
-	my $myconfig = join '', <$fh>;
-	close $fh or return;
-	return $myconfig eq Config->myconfig;
+
+	my $pid = open2(my($in, $out), @cmd);
+	my $ret = do { local $/; <$in> };
+	waitpid $pid, 0;
+	return $ret eq Config->myconfig;
 }
 
 1;
@@ -131,7 +132,7 @@ Devel::FindPerl - Find the path to your perl
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 DESCRIPTION
 
